==> client-java-api-fluent-16.0.2-sources.jar: io/kubernetes/client/openapi/models/V1ConfigMapListBuilder.java <==
/*
Copyright 2022 The Kubernetes Authors.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;

public class V1ConfigMapListBuilder extends V1ConfigMapListFluentImpl<V1ConfigMapListBuilder>
    implements VisitableBuilder<
        io.kubernetes.client.openapi.models.V1ConfigMapList, V1ConfigMapListBuilder> {
  public V1ConfigMapListBuilder() {
    this(false);
  }

  public V1ConfigMapListBuilder(Boolean validationEnabled) {
    this(new V1ConfigMapList(), validationEnabled);
  }

  public V1ConfigMapListBuilder(V1ConfigMapListFluent<?> fluent) {
    this(fluent, false);
  }

  public V1ConfigMapListBuilder(
      io.kubernetes.client.openapi.models.V1ConfigMapListFluent<?> fluent,
      java.lang.Boolean validationEnabled) {
    this(fluent, new V1ConfigMapList(), validationEnabled);
  }

  public V1ConfigMapListBuilder(
      io.kubernetes.client.openapi.models.V1ConfigMapListFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1ConfigMapList instance) {
    this(fluent, instance, false);
  }

  public V1ConfigMapListBuilder(
      io.kubernetes.client.openapi.models.V1ConfigMapListFluent<?> fluent,
      io.kubernetes.client.openapi.models.V1ConfigMapList instance,
      java.lang.Boolean validationEnabled) {
    this.fluent = fluent;
    fluent.withApiVersion(instance.getApiVersion());

    fluent.withItems(instance.getItems());

    fluent.withKind(instance.getKind());

    fluent.withMetadata(instance.getMetadata());

    this.validationEnabled = validationEnabled;
  }

  public V1ConfigMapListBuilder(io.kubernetes.client.openapi.models.V1ConfigMapList instance) {
    this(instance, false);
  }

  public V1ConfigMapListBuilder(
      io.kubernetes.client.openapi.models.V1ConfigMapList instance,
      java.lang.Boolean validationEnabled) {
    this.fluent = this;
    this.withApiVersion(instance.getApiVersion());

    this.withItems(instance.getItems());

    this.withKind(instance.getKind());

    this.withMetadata(instance.getMetadata());

    this.validationEnabled = validationEnabled;
  }

  io.kubernetes.client.openapi.models.V1ConfigMapListFluent<?> fluent;
  java.lang.Boolean validationEnabled;

  public io.kubernetes.client.openapi.models.V1ConfigMapList build() {
    V1ConfigMapList buildable = new V1ConfigMapList();
    buildable.setApiVersion(fluent.getApiVersion());
    buildable.setItems(fluent.getItems());
    buildable.setKind(fluent.getKind());
    buildable.setMetadata(fluent.getMetadata());
    return buildable;
  }
}

==> client-java-api-fluent-17.0.2-sources.jar: io/kubernetes/client/openapi/models/V1ConfigMapListBuilder.java <==
package io.kubernetes.client.openapi.models;

import io.kubernetes.client.fluent.VisitableBuilder;
import java.lang.Boolean;
public class V1ConfigMapListBuilder extends V1ConfigMapListFluentImpl<V1ConfigMapListBuilder> implements VisitableBuilder<V1ConfigMapList,V1ConfigMapListBuilder>{
  public V1ConfigMapListBuilder() {
    this(false);
  }
  public V1ConfigMapListBuilder(Boolean validationEnabled) {
    this(new V1ConfigMapList(), validationEnabled);
  }
  public V1ConfigMapListBuilder(V1ConfigMapListFluent<?> fluent) {
    this(fluent, false);
  }
  public V1ConfigMapListBuilder(V1ConfigMapListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new V1ConfigMapList(), validationEnabled);
  }
  public V1ConfigMapListBuilder(V1ConfigMapListFluent<?> fluent,V1ConfigMapList instance) {
    this(fluent, instance, false);
  }
  public V1ConfigMapListBuilder(V1ConfigMapListFluent<?> fluent,V1ConfigMapList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion());

    fluent.withItems(instance.getItems());

    fluent.withKind(instance.getKind());

    fluent.withMetadata(instance.getMetadata());

    this.validationEnabled = validationEnabled; 
  }
  public V1ConfigMapListBuilder(V1ConfigMapList instance) {
    this(instance,false);
  }
  public V1ConfigMapListBuilder(V1ConfigMapList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion());

    this.withItems(instance.getItems());

    this.withKind(instance.getKind());

    this.withMetadata(instance.getMetadata());

    this.validationEnabled = validationEnabled; 
  }
  V1ConfigMapListFluent<?> fluent;
  Boolean validationEnabled;
  public V1ConfigMapList build() {
    V1ConfigMapList buildable = new V1ConfigMapList();
    buildable.setApiVersion(fluent.getApiVersion());
    buildable.setItems(fluent.getItems());
    buildable.setKind(fluent.getKind());
    buildable.setMetadata(fluent.getMetadata());
    return buildable;
  }
  
}
